diff --git a/src/wp-activate.php b/src/wp-activate.php
index 36772a2d9d..70cf4dfb84 100644
--- a/src/wp-activate.php
+++ b/src/wp-activate.php
@@ -175,7 +175,7 @@ $blog_details = get_site();
 			<?php
 		} else {
 			$url  = isset( $result['blog_id'] ) ? get_home_url( (int) $result['blog_id'] ) : '';
-			$user = get_userdata( (int) $result['user_id'] );
+			$user = get_user( (int) $result['user_id'] );
 			?>
 			<h2><?php _e( 'Your account is now active!' ); ?></h2>
 
diff --git a/src/wp-admin/edit-form-advanced.php b/src/wp-admin/edit-form-advanced.php
index 16b699ca39..965775391b 100644
--- a/src/wp-admin/edit-form-advanced.php
+++ b/src/wp-admin/edit-form-advanced.php
@@ -647,7 +647,7 @@ if ( post_type_supports( $post_type, 'editor' ) ) {
 	<?php
 	if ( 'auto-draft' !== $post->post_status ) {
 		echo '<span id="last-edit">';
-		$last_user = get_userdata( get_post_meta( $post->ID, '_edit_last', true ) );
+		$last_user = get_user( get_post_meta( $post->ID, '_edit_last', true ) );
 		if ( $last_user ) {
 			printf(
 				/* translators: 1: Name of most recent post author, 2: Post edited date, 3: Post edited time. */
diff --git a/src/wp-admin/edit-form-blocks.php b/src/wp-admin/edit-form-blocks.php
index 93dea2eb91..09a7f3df3a 100644
--- a/src/wp-admin/edit-form-blocks.php
+++ b/src/wp-admin/edit-form-blocks.php
@@ -154,7 +154,7 @@ if ( $user_id ) {
 
 	$user_details = null;
 	if ( $locked ) {
-		$user         = get_userdata( $user_id );
+		$user         = get_user( $user_id );
 		$user_details = array(
 			'avatar' => get_avatar_url( $user_id, array( 'size' => 128 ) ),
 			'name'   => $user->display_name,
diff --git a/src/wp-admin/includes/ajax-actions.php b/src/wp-admin/includes/ajax-actions.php
index b8e8246eb7..301d577c72 100644
--- a/src/wp-admin/includes/ajax-actions.php
+++ b/src/wp-admin/includes/ajax-actions.php
@@ -1759,7 +1759,7 @@ function wp_ajax_add_user( $action ) {
 		$x->send();
 	}
 
-	$user_object   = get_userdata( $user_id );
+	$user_object   = get_user( $user_id );
 	$wp_list_table = _get_list_table( 'WP_Users_List_Table' );
 
 	$role = current( $user_object->roles );
@@ -2074,7 +2074,7 @@ function wp_ajax_inline_save() {
 
 	$last = wp_check_post_lock( $post_id );
 	if ( $last ) {
-		$last_user      = get_userdata( $last );
+		$last_user      = get_user( $last );
 		$last_user_name = $last_user ? $last_user->display_name : __( 'Someone' );
 
 		/* translators: %s: User's display name. */
@@ -2890,7 +2890,7 @@ function wp_ajax_wp_fullscreen_save_post() {
 
 	$last_id = get_post_meta( $post_id, '_edit_last', true );
 	if ( $last_id ) {
-		$last_user = get_userdata( $last_id );
+		$last_user = get_user( $last_id );
 		/* translators: 1: User's display name, 2: Date of last edit, 3: Time of last edit. */
 		$last_edited = sprintf( __( 'Last edited by %1$s on %2$s at %3$s' ), esc_html( $last_user->display_name ), $last_date, $last_time );
 	} else {
@@ -3964,7 +3964,7 @@ function wp_ajax_parse_media_shortcode() {
  * @since 4.1.0
  */
 function wp_ajax_destroy_sessions() {
-	$user = get_userdata( (int) $_POST['user_id'] );
+	$user = get_user( (int) $_POST['user_id'] );
 
 	if ( $user ) {
 		if ( ! current_user_can( 'edit_user', $user->ID ) ) {
@@ -5603,7 +5603,7 @@ function wp_ajax_send_password_reset() {
 	}
 
 	// Send the password reset link.
-	$user    = get_userdata( $user_id );
+	$user    = get_user( $user_id );
 	$results = retrieve_password( $user->user_login );
 
 	if ( true === $results ) {
diff --git a/src/wp-admin/includes/class-wp-posts-list-table.php b/src/wp-admin/includes/class-wp-posts-list-table.php
index baf3ef6c6f..e67b5e2653 100644
--- a/src/wp-admin/includes/class-wp-posts-list-table.php
+++ b/src/wp-admin/includes/class-wp-posts-list-table.php
@@ -1115,7 +1115,7 @@ class WP_Posts_List_Table extends WP_List_Table {
 			$lock_holder = wp_check_post_lock( $post->ID );
 
 			if ( $lock_holder ) {
-				$lock_holder   = get_userdata( $lock_holder );
+				$lock_holder   = get_user( $lock_holder );
 				$locked_avatar = get_avatar( $lock_holder->ID, 18 );
 				/* translators: %s: User's display name. */
 				$locked_text = esc_html( sprintf( __( '%s is currently editing' ), $lock_holder->display_name ) );
diff --git a/src/wp-admin/includes/class-wp-users-list-table.php b/src/wp-admin/includes/class-wp-users-list-table.php
index 8dfe3ce1a3..dd91559c32 100644
--- a/src/wp-admin/includes/class-wp-users-list-table.php
+++ b/src/wp-admin/includes/class-wp-users-list-table.php
@@ -432,7 +432,7 @@ class WP_Users_List_Table extends WP_List_Table {
 	 */
 	public function single_row( $user_object, $style = '', $role = '', $numposts = 0 ) {
 		if ( ! ( $user_object instanceof WP_User ) ) {
-			$user_object = get_userdata( (int) $user_object );
+			$user_object = get_user( (int) $user_object );
 		}
 		$user_object->filter = 'display';
 		$email               = $user_object->user_email;
diff --git a/src/wp-admin/includes/deprecated.php b/src/wp-admin/includes/deprecated.php
index f7805b4cc7..822d6ffaba 100644
--- a/src/wp-admin/includes/deprecated.php
+++ b/src/wp-admin/includes/deprecated.php
@@ -286,7 +286,7 @@ function get_editable_user_ids( $user_id, $exclude_zeros = true, $post_type = 'p
 
 	global $wpdb;
 
-	if ( ! $user = get_userdata( $user_id ) )
+	if ( ! $user = get_user( $user_id ) )
 		return array();
 	$post_type_obj = get_post_type_object($post_type);
 
diff --git a/src/wp-admin/includes/export.php b/src/wp-admin/includes/export.php
index 9610ac8c9f..f48e2ae427 100644
--- a/src/wp-admin/includes/export.php
+++ b/src/wp-admin/includes/export.php
@@ -368,7 +368,7 @@ function export_wp( $args = array() ) {
 		$authors = array();
 		$results = $wpdb->get_results( "SELECT DISTINCT post_author FROM $wpdb->posts WHERE post_status != 'auto-draft' $and" );
 		foreach ( (array) $results as $result ) {
-			$authors[] = get_userdata( $result->post_author );
+			$authors[] = get_user( $result->post_author );
 		}
 
 		$authors = array_filter( $authors );
diff --git a/src/wp-admin/includes/misc.php b/src/wp-admin/includes/misc.php
index 3f48065cdf..51a5fa5ba2 100644
--- a/src/wp-admin/includes/misc.php
+++ b/src/wp-admin/includes/misc.php
@@ -1148,7 +1148,7 @@ function wp_check_locked_posts( $response, $data, $screen_id ) {
 			$user_id = wp_check_post_lock( $post_id );
 
 			if ( $user_id ) {
-				$user = get_userdata( $user_id );
+				$user = get_user( $user_id );
 
 				if ( $user && current_user_can( 'edit_post', $post_id ) ) {
 					$send = array(
@@ -1201,7 +1201,7 @@ function wp_refresh_post_lock( $response, $data, $screen_id ) {
 		}
 
 		$user_id = wp_check_post_lock( $post_id );
-		$user    = get_userdata( $user_id );
+		$user    = get_user( $user_id );
 
 		if ( $user ) {
 			$error = array(
diff --git a/src/wp-admin/includes/ms.php b/src/wp-admin/includes/ms.php
index 02ddf945aa..cc603e94df 100644
--- a/src/wp-admin/includes/ms.php
+++ b/src/wp-admin/includes/ms.php
@@ -330,7 +330,7 @@ function upload_space_setting( $id ) {
 function refresh_user_details( $id ) {
 	$id = (int) $id;
 
-	$user = get_userdata( $id );
+	$user = get_user( $id );
 	if ( ! $user ) {
 		return false;
 	}
@@ -883,7 +883,7 @@ function confirm_delete_users( $users ) {
 	$allusers = (array) $_POST['allusers'];
 	foreach ( $allusers as $user_id ) {
 		if ( '' !== $user_id && '0' !== $user_id ) {
-			$delete_user = get_userdata( $user_id );
+			$delete_user = get_user( $user_id );
 
 			if ( ! current_user_can( 'delete_user', $delete_user->ID ) ) {
 				wp_die(
diff --git a/src/wp-admin/includes/post.php b/src/wp-admin/includes/post.php
index c93ac71bec..6f6525af3f 100644
--- a/src/wp-admin/includes/post.php
+++ b/src/wp-admin/includes/post.php
@@ -1700,7 +1700,7 @@ function wp_check_post_lock( $post ) {
 	$time = $lock[0];
 	$user = isset( $lock[1] ) ? $lock[1] : get_post_meta( $post->ID, '_edit_last', true );
 
-	if ( ! get_userdata( $user ) ) {
+	if ( ! get_user( $user ) ) {
 		return false;
 	}
 
@@ -1765,7 +1765,7 @@ function _admin_notice_post_locked() {
 	$user_id = wp_check_post_lock( $post->ID );
 
 	if ( $user_id ) {
-		$user = get_userdata( $user_id );
+		$user = get_user( $user_id );
 	}
 
 	if ( $user ) {
diff --git a/src/wp-admin/includes/user.php b/src/wp-admin/includes/user.php
index abed2d2015..813cd8db5a 100644
--- a/src/wp-admin/includes/user.php
+++ b/src/wp-admin/includes/user.php
@@ -34,7 +34,7 @@ function edit_user( $user_id = 0 ) {
 	if ( $user_id ) {
 		$update           = true;
 		$user->ID         = $user_id;
-		$userdata         = get_userdata( $user_id );
+		$userdata         = get_user( $user_id );
 		$user->user_login = wp_slash( $userdata->user_login );
 	} else {
 		$update = false;
@@ -289,7 +289,7 @@ function get_editable_roles() {
  * @return WP_User|false WP_User object on success, false on failure.
  */
 function get_user_to_edit( $user_id ) {
-	$user = get_userdata( $user_id );
+	$user = get_user( $user_id );
 
 	if ( $user ) {
 		$user->filter = 'edit';
@@ -514,7 +514,7 @@ function default_password_nag_edit_user( $user_ID, $old_data ) {
 		return;
 	}
 
-	$new_data = get_userdata( $user_ID );
+	$new_data = get_user( $user_ID );
 
 	// Remove the nag if the password has been changed.
 	if ( $new_data->user_pass !== $old_data->user_pass ) {
diff --git a/src/wp-admin/network/site-users.php b/src/wp-admin/network/site-users.php
index 78af65b9ed..cb8ece30d2 100644
--- a/src/wp-admin/network/site-users.php
+++ b/src/wp-admin/network/site-users.php
@@ -161,7 +161,7 @@ if ( $action ) {
 						);
 					}
 
-					$user = get_userdata( $user_id );
+					$user = get_user( $user_id );
 					$user->set_role( $role );
 				}
 			} else {
diff --git a/src/wp-admin/network/users.php b/src/wp-admin/network/users.php
index d0b40e710d..eef3e2e705 100644
--- a/src/wp-admin/network/users.php
+++ b/src/wp-admin/network/users.php
@@ -79,7 +79,7 @@ if ( isset( $_GET['action'] ) ) {
 								exit;
 
 							case 'spam':
-								$user = get_userdata( $user_id );
+								$user = get_user( $user_id );
 								if ( is_super_admin( $user->ID ) ) {
 									wp_die(
 										sprintf(
@@ -106,7 +106,7 @@ if ( isset( $_GET['action'] ) ) {
 								break;
 
 							case 'notspam':
-								$user = get_userdata( $user_id );
+								$user = get_user( $user_id );
 
 								$userfunction = 'all_notspam';
 								$blogs        = get_blogs_of_user( $user_id, true );
diff --git a/src/wp-admin/post.php b/src/wp-admin/post.php
index 17875cb3e5..f44102262b 100644
--- a/src/wp-admin/post.php
+++ b/src/wp-admin/post.php
@@ -252,7 +252,7 @@ switch ( $action ) {
 
 		$user_id = wp_check_post_lock( $post_id );
 		if ( $user_id ) {
-			$user = get_userdata( $user_id );
+			$user = get_user( $user_id );
 			/* translators: %s: User's display name. */
 			wp_die( sprintf( __( 'You cannot move this item to the Trash. %s is currently editing.' ), $user->display_name ) );
 		}
diff --git a/src/wp-admin/user-edit.php b/src/wp-admin/user-edit.php
index bbb321a272..b77a78dc6d 100644
--- a/src/wp-admin/user-edit.php
+++ b/src/wp-admin/user-edit.php
@@ -25,7 +25,7 @@ if ( ! $user_id && IS_PROFILE_PAGE ) {
 	$user_id = $current_user->ID;
 } elseif ( ! $user_id && ! IS_PROFILE_PAGE ) {
 	wp_die( __( 'Invalid user ID.' ) );
-} elseif ( ! get_userdata( $user_id ) ) {
+} elseif ( ! get_user( $user_id ) ) {
 	wp_die( __( 'Invalid user ID.' ) );
 }
 
@@ -159,7 +159,7 @@ switch ( $action ) {
 
 		// Update the email address in signups, if present.
 		if ( is_multisite() ) {
-			$user = get_userdata( $user_id );
+			$user = get_user( $user_id );
 
 			if ( $user->user_login && isset( $_POST['email'] ) && is_email( $_POST['email'] ) && $wpdb->get_var( $wpdb->prepare( "SELECT user_login FROM {$wpdb->signups} WHERE user_login = %s", $user->user_login ) ) ) {
 				$wpdb->query( $wpdb->prepare( "UPDATE {$wpdb->signups} SET user_email = %s WHERE user_login = %s", $_POST['email'], $user_login ) );
diff --git a/src/wp-admin/users.php b/src/wp-admin/users.php
index 94d891ae0c..ab997a13f2 100644
--- a/src/wp-admin/users.php
+++ b/src/wp-admin/users.php
@@ -161,7 +161,7 @@ switch ( $wp_list_table->current_action() ) {
 				);
 			}
 
-			$user = get_userdata( $id );
+			$user = get_user( $id );
 			$user->set_role( $role );
 		}
 
@@ -255,7 +255,7 @@ switch ( $wp_list_table->current_action() ) {
 			}
 
 			// Send the password reset link.
-			$user = get_userdata( $id );
+			$user = get_user( $id );
 			if ( true === retrieve_password( $user->user_login ) ) {
 				++$reset_count;
 			}
@@ -361,7 +361,7 @@ switch ( $wp_list_table->current_action() ) {
 		$go_delete = 0;
 
 		foreach ( $all_user_ids as $id ) {
-			$user = get_userdata( $id );
+			$user = get_user( $id );
 
 			if ( $id === $current_user->ID ) {
 				echo '<li>';
@@ -528,7 +528,7 @@ switch ( $wp_list_table->current_action() ) {
 		$go_remove = false;
 
 		foreach ( $user_ids as $id ) {
-			$user = get_userdata( $id );
+			$user = get_user( $id );
 
 			if ( ! current_user_can( 'remove_user', $id ) ) {
 				echo '<li>';
diff --git a/src/wp-content/themes/twentynineteen/inc/helper-functions.php b/src/wp-content/themes/twentynineteen/inc/helper-functions.php
index c18275604a..49a991913e 100644
--- a/src/wp-content/themes/twentynineteen/inc/helper-functions.php
+++ b/src/wp-content/themes/twentynineteen/inc/helper-functions.php
@@ -35,7 +35,7 @@ function twentynineteen_get_avatar_size() {
  */
 function twentynineteen_is_comment_by_post_author( $comment = null ) {
 	if ( is_object( $comment ) && $comment->user_id > 0 ) {
-		$user = get_userdata( $comment->user_id );
+		$user = get_user( $comment->user_id );
 		$post = get_post( $comment->comment_post_ID );
 		if ( ! empty( $user ) && ! empty( $post ) ) {
 			return $comment->user_id === $post->post_author;
diff --git a/src/wp-content/themes/twentytwenty/inc/template-tags.php b/src/wp-content/themes/twentytwenty/inc/template-tags.php
index 8014eb4123..2b2ac62af2 100644
--- a/src/wp-content/themes/twentytwenty/inc/template-tags.php
+++ b/src/wp-content/themes/twentytwenty/inc/template-tags.php
@@ -143,7 +143,7 @@ function twentytwenty_is_comment_by_post_author( $comment = null ) {
 
 	if ( is_object( $comment ) && $comment->user_id > 0 ) {
 
-		$user = get_userdata( $comment->user_id );
+		$user = get_user( $comment->user_id );
 		$post = get_post( $comment->comment_post_ID );
 
 		if ( ! empty( $user ) && ! empty( $post ) ) {
diff --git a/src/wp-includes/admin-bar.php b/src/wp-includes/admin-bar.php
index 3eba2668fa..ce6e6cfeb3 100644
--- a/src/wp-includes/admin-bar.php
+++ b/src/wp-includes/admin-bar.php
@@ -873,7 +873,7 @@ function wp_admin_bar_edit_menu( $wp_admin_bar ) {
 				);
 			}
 		} elseif ( 'user-edit' === $current_screen->base && isset( $user_id ) ) {
-			$user_object = get_userdata( $user_id );
+			$user_object = get_user( $user_id );
 			$view_link   = get_author_posts_url( $user_object->ID );
 			if ( $user_object->exists() && $view_link ) {
 				$wp_admin_bar->add_node(
diff --git a/src/wp-includes/author-template.php b/src/wp-includes/author-template.php
index 184d7d0f38..825e3a14f9 100644
--- a/src/wp-includes/author-template.php
+++ b/src/wp-includes/author-template.php
@@ -93,7 +93,7 @@ function get_the_modified_author() {
 	$last_id = get_post_meta( get_post()->ID, '_edit_last', true );
 
 	if ( $last_id ) {
-		$last_user = get_userdata( $last_id );
+		$last_user = get_user( $last_id );
 
 		/**
 		 * Filters the display name of the author who last edited the current post.
@@ -166,7 +166,7 @@ function get_the_author_meta( $field = '', $user_id = false ) {
 		global $authordata;
 		$user_id = isset( $authordata->ID ) ? $authordata->ID : 0;
 	} else {
-		$authordata = get_userdata( $user_id );
+		$authordata = get_user( $user_id );
 	}
 
 	if ( in_array( $field, array( 'login', 'pass', 'nicename', 'email', 'url', 'registered', 'activation_key', 'status' ), true ) ) {
@@ -372,7 +372,7 @@ function get_author_posts_url( $author_id, $author_nicename = '' ) {
 		$link = $file . '?author=' . $author_id;
 	} else {
 		if ( '' === $author_nicename ) {
-			$user = get_userdata( $author_id );
+			$user = get_user( $author_id );
 			if ( ! empty( $user->user_nicename ) ) {
 				$author_nicename = $user->user_nicename;
 			}
@@ -503,7 +503,7 @@ function wp_list_authors( $args = '' ) {
 			continue;
 		}
 
-		$author = get_userdata( $author_id );
+		$author = get_user( $author_id );
 
 		if ( $parsed_args['exclude_admin'] && 'admin' === $author->display_name ) {
 			continue;
diff --git a/src/wp-includes/canonical.php b/src/wp-includes/canonical.php
index 0b94791fd9..8755af3921 100644
--- a/src/wp-includes/canonical.php
+++ b/src/wp-includes/canonical.php
@@ -319,7 +319,7 @@ function redirect_canonical( $requested_url = null, $do_redirect = true ) {
 		} elseif ( is_author() && ! empty( $_GET['author'] )
 			&& is_string( $_GET['author'] ) && preg_match( '|^[0-9]+$|', $_GET['author'] )
 		) {
-			$author = get_userdata( get_query_var( 'author' ) );
+			$author = get_user( get_query_var( 'author' ) );
 
 			if ( false !== $author
 				&& $wpdb->get_var( $wpdb->prepare( "SELECT ID FROM $wpdb->posts WHERE $wpdb->posts.post_author = %d AND $wpdb->posts.post_status = 'publish' LIMIT 1", $author->ID ) )
diff --git a/src/wp-includes/capabilities.php b/src/wp-includes/capabilities.php
index 26b150fe4b..e718344bc2 100644
--- a/src/wp-includes/capabilities.php
+++ b/src/wp-includes/capabilities.php
@@ -940,7 +940,7 @@ function author_can( $post, $capability, ...$args ) {
 		return false;
 	}
 
-	$author = get_userdata( $post->post_author );
+	$author = get_user( $post->post_author );
 
 	if ( ! $author ) {
 		return false;
@@ -973,7 +973,7 @@ function author_can( $post, $capability, ...$args ) {
  */
 function user_can( $user, $capability, ...$args ) {
 	if ( ! is_object( $user ) ) {
-		$user = get_userdata( $user );
+		$user = get_user( $user );
 	}
 
 	if ( empty( $user ) ) {
@@ -1076,7 +1076,7 @@ function is_super_admin( $user_id = false ) {
 	if ( ! $user_id ) {
 		$user = wp_get_current_user();
 	} else {
-		$user = get_userdata( $user_id );
+		$user = get_user( $user_id );
 	}
 
 	if ( ! $user || ! $user->exists() ) {
@@ -1126,7 +1126,7 @@ function grant_super_admin( $user_id ) {
 	// Directly fetch site_admins instead of using get_super_admins().
 	$super_admins = get_site_option( 'site_admins', array( 'admin' ) );
 
-	$user = get_userdata( $user_id );
+	$user = get_user( $user_id );
 	if ( $user && ! in_array( $user->user_login, $super_admins, true ) ) {
 		$super_admins[] = $user->user_login;
 		update_site_option( 'site_admins', $super_admins );
@@ -1173,7 +1173,7 @@ function revoke_super_admin( $user_id ) {
 	// Directly fetch site_admins instead of using get_super_admins().
 	$super_admins = get_site_option( 'site_admins', array( 'admin' ) );
 
-	$user = get_userdata( $user_id );
+	$user = get_user( $user_id );
 	if ( $user && 0 !== strcasecmp( $user->user_email, get_site_option( 'admin_email' ) ) ) {
 		$key = array_search( $user->user_login, $super_admins, true );
 		if ( false !== $key ) {
diff --git a/src/wp-includes/class-wp-customize-manager.php b/src/wp-includes/class-wp-customize-manager.php
index d12eea0e5f..b6f4c0cf4b 100644
--- a/src/wp-includes/class-wp-customize-manager.php
+++ b/src/wp-includes/class-wp-customize-manager.php
@@ -3323,7 +3323,7 @@ final class WP_Customize_Manager {
 			return null;
 		}
 
-		$lock_user = get_userdata( $user_id );
+		$lock_user = get_user( $user_id );
 
 		if ( ! $lock_user ) {
 			return null;
diff --git a/src/wp-includes/class-wp-query.php b/src/wp-includes/class-wp-query.php
index e6a3e6b743..6ee572c744 100644
--- a/src/wp-includes/class-wp-query.php
+++ b/src/wp-includes/class-wp-query.php
@@ -3917,7 +3917,7 @@ class WP_Query {
 				}
 			}
 
-			$this->queried_object = get_userdata( $this->queried_object_id );
+			$this->queried_object = get_user( $this->queried_object_id );
 		}
 
 		return $this->queried_object;
@@ -4749,7 +4749,7 @@ class WP_Query {
 
 		$id = (int) $post->ID;
 
-		$authordata = get_userdata( $post->post_author );
+		$authordata = get_user( $post->post_author );
 
 		$currentday   = false;
 		$currentmonth = false;
diff --git a/src/wp-includes/class-wp-xmlrpc-server.php b/src/wp-includes/class-wp-xmlrpc-server.php
index ae9a658718..d5d4e970cd 100644
--- a/src/wp-includes/class-wp-xmlrpc-server.php
+++ b/src/wp-includes/class-wp-xmlrpc-server.php
@@ -1124,7 +1124,7 @@ class wp_xmlrpc_server extends IXR_Server {
 		}
 
 		// Get the author info.
-		$author = get_userdata( $page->post_author );
+		$author = get_user( $page->post_author );
 
 		$page_template = get_page_template_slug( $page->ID );
 		if ( empty( $page_template ) ) {
@@ -1493,7 +1493,7 @@ class wp_xmlrpc_server extends IXR_Server {
 				return new IXR_Error( 401, __( 'Sorry, you are not allowed to create posts as this user.' ) );
 			}
 
-			$author = get_userdata( $post_data['post_author'] );
+			$author = get_user( $post_data['post_author'] );
 
 			if ( ! $author ) {
 				return new IXR_Error( 404, __( 'Invalid author ID.' ) );
@@ -2649,7 +2649,7 @@ class wp_xmlrpc_server extends IXR_Server {
 	 * names can be used to specify multiple fields. The available conceptual
 	 * groups are 'basic' and 'all'.
 	 *
-	 * @uses get_userdata()
+	 * @uses get_user()
 	 *
 	 * @param array $args {
 	 *     Method arguments. Note: arguments must be ordered as documented.
@@ -2711,7 +2711,7 @@ class wp_xmlrpc_server extends IXR_Server {
 			return new IXR_Error( 401, __( 'Sorry, you are not allowed to edit this user.' ) );
 		}
 
-		$user_data = get_userdata( $user_id );
+		$user_data = get_user( $user_id );
 
 		if ( ! $user_data ) {
 			return new IXR_Error( 404, __( 'Invalid user ID.' ) );
@@ -2813,7 +2813,7 @@ class wp_xmlrpc_server extends IXR_Server {
 	/**
 	 * Retrieves information about the requesting user.
 	 *
-	 * @uses get_userdata()
+	 * @uses get_user()
 	 *
 	 * @param array $args {
 	 *     Method arguments. Note: arguments must be ordered as documented.
@@ -2854,7 +2854,7 @@ class wp_xmlrpc_server extends IXR_Server {
 			return new IXR_Error( 401, __( 'Sorry, you are not allowed to edit your profile.' ) );
 		}
 
-		$user_data = get_userdata( $user->ID );
+		$user_data = get_user( $user->ID );
 
 		return $this->_prepare_user( $user_data, $fields );
 	}
@@ -5464,7 +5464,7 @@ class wp_xmlrpc_server extends IXR_Server {
 				default:
 					return new IXR_Error( 401, __( 'Invalid post type.' ) );
 			}
-			$author = get_userdata( $content_struct['wp_author_id'] );
+			$author = get_user( $content_struct['wp_author_id'] );
 			if ( ! $author ) {
 				return new IXR_Error( 404, __( 'Invalid author ID.' ) );
 			}
@@ -6106,7 +6106,7 @@ class wp_xmlrpc_server extends IXR_Server {
 			$link = get_permalink( $postdata['ID'] );
 
 			// Get the author info.
-			$author = get_userdata( $postdata['post_author'] );
+			$author = get_user( $postdata['post_author'] );
 
 			$allow_comments = ( 'open' === $postdata['comment_status'] ) ? 1 : 0;
 			$allow_pings    = ( 'open' === $postdata['ping_status'] ) ? 1 : 0;
@@ -6258,7 +6258,7 @@ class wp_xmlrpc_server extends IXR_Server {
 			$link = get_permalink( $entry['ID'] );
 
 			// Get the post author info.
-			$author = get_userdata( $entry['post_author'] );
+			$author = get_user( $entry['post_author'] );
 
 			$allow_comments = ( 'open' === $entry['comment_status'] ) ? 1 : 0;
 			$allow_pings    = ( 'open' === $entry['ping_status'] ) ? 1 : 0;
diff --git a/src/wp-includes/class-wp.php b/src/wp-includes/class-wp.php
index ce88c102cf..0213beeb2f 100644
--- a/src/wp-includes/class-wp.php
+++ b/src/wp-includes/class-wp.php
@@ -670,7 +670,7 @@ class WP {
 		}
 
 		if ( $wp_query->is_author() ) {
-			$GLOBALS['authordata'] = get_userdata( get_queried_object_id() );
+			$GLOBALS['authordata'] = get_user( get_queried_object_id() );
 		}
 	}
 
diff --git a/src/wp-includes/comment-template.php b/src/wp-includes/comment-template.php
index a1005d56e2..78249fbc17 100644
--- a/src/wp-includes/comment-template.php
+++ b/src/wp-includes/comment-template.php
@@ -27,7 +27,7 @@ function get_comment_author( $comment_id = 0 ) {
 	$comment_id = ! empty( $comment->comment_ID ) ? $comment->comment_ID : $comment_id;
 
 	if ( empty( $comment->comment_author ) ) {
-		$user = ! empty( $comment->user_id ) ? get_userdata( $comment->user_id ) : false;
+		$user = ! empty( $comment->user_id ) ? get_user( $comment->user_id ) : false;
 		if ( $user ) {
 			$comment_author = $user->display_name;
 		} else {
@@ -519,7 +519,7 @@ function get_comment_class( $css_class = '', $comment_id = null, $post = null )
 	$classes[] = ( empty( $comment->comment_type ) ) ? 'comment' : $comment->comment_type;
 
 	// Add classes for comment authors that are registered users.
-	$user = $comment->user_id ? get_userdata( $comment->user_id ) : false;
+	$user = $comment->user_id ? get_user( $comment->user_id ) : false;
 	if ( $user ) {
 		$classes[] = 'byuser';
 		$classes[] = 'comment-author-' . sanitize_html_class( $user->user_nicename, $comment->user_id );
diff --git a/src/wp-includes/comment.php b/src/wp-includes/comment.php
index de23a72130..e342a7f9d9 100644
--- a/src/wp-includes/comment.php
+++ b/src/wp-includes/comment.php
@@ -772,7 +772,7 @@ function wp_allow_comment( $commentdata, $wp_error = false ) {
 	}
 
 	if ( ! empty( $commentdata['user_id'] ) ) {
-		$user        = get_userdata( $commentdata['user_id'] );
+		$user        = get_user( $commentdata['user_id'] );
 		$post_author = $wpdb->get_var(
 			$wpdb->prepare(
 				"SELECT post_author FROM $wpdb->posts WHERE ID = %d LIMIT 1",
diff --git a/src/wp-includes/deprecated.php b/src/wp-includes/deprecated.php
index e63708f91b..cabf5f5076 100644
--- a/src/wp-includes/deprecated.php
+++ b/src/wp-includes/deprecated.php
@@ -206,7 +206,7 @@ function next_post($format='%', $next='next post: ', $title='yes', $in_same_cat=
 function user_can_create_post($user_id, $blog_id = 1, $category_id = 'None') {
 	_deprecated_function( __FUNCTION__, '2.0.0', 'current_user_can()' );
 
-	$author_data = get_userdata($user_id);
+	$author_data = get_user($user_id);
 	return ($author_data->user_level > 1);
 }
 
@@ -225,7 +225,7 @@ function user_can_create_post($user_id, $blog_id = 1, $category_id = 'None') {
 function user_can_create_draft($user_id, $blog_id = 1, $category_id = 'None') {
 	_deprecated_function( __FUNCTION__, '2.0.0', 'current_user_can()' );
 
-	$author_data = get_userdata($user_id);
+	$author_data = get_user($user_id);
 	return ($author_data->user_level >= 1);
 }
 
@@ -244,9 +244,9 @@ function user_can_create_draft($user_id, $blog_id = 1, $category_id = 'None') {
 function user_can_edit_post($user_id, $post_id, $blog_id = 1) {
 	_deprecated_function( __FUNCTION__, '2.0.0', 'current_user_can()' );
 
-	$author_data = get_userdata($user_id);
+	$author_data = get_user($user_id);
 	$post = get_post($post_id);
-	$post_author_data = get_userdata($post->post_author);
+	$post_author_data = get_user($post->post_author);
 
 	if ( (($user_id == $post_author_data->ID) && !($post->post_status == 'publish' && $author_data->user_level < 2))
 			|| ($author_data->user_level > $post_author_data->user_level)
@@ -291,7 +291,7 @@ function user_can_delete_post($user_id, $post_id, $blog_id = 1) {
 function user_can_set_post_date($user_id, $blog_id = 1, $category_id = 'None') {
 	_deprecated_function( __FUNCTION__, '2.0.0', 'current_user_can()' );
 
-	$author_data = get_userdata($user_id);
+	$author_data = get_user($user_id);
 	return (($author_data->user_level > 4) && user_can_create_post($user_id, $blog_id, $category_id));
 }
 
@@ -310,7 +310,7 @@ function user_can_set_post_date($user_id, $blog_id = 1, $category_id = 'None') {
 function user_can_edit_post_date($user_id, $post_id, $blog_id = 1) {
 	_deprecated_function( __FUNCTION__, '2.0.0', 'current_user_can()' );
 
-	$author_data = get_userdata($user_id);
+	$author_data = get_user($user_id);
 	return (($author_data->user_level > 4) && user_can_edit_post($user_id, $post_id, $blog_id));
 }
 
@@ -366,8 +366,8 @@ function user_can_delete_post_comments($user_id, $post_id, $blog_id = 1) {
 function user_can_edit_user($user_id, $other_user) {
 	_deprecated_function( __FUNCTION__, '2.0.0', 'current_user_can()' );
 
-	$user  = get_userdata($user_id);
-	$other = get_userdata($other_user);
+	$user  = get_user($user_id);
+	$other = get_user($other_user);
 	if ( $user->user_level > $other->user_level || $user->user_level > 8 || $user->ID == $other->ID )
 		return true;
 	else
diff --git a/src/wp-includes/embed.php b/src/wp-includes/embed.php
index 9e59f1abc0..2adb1b2020 100644
--- a/src/wp-includes/embed.php
+++ b/src/wp-includes/embed.php
@@ -589,7 +589,7 @@ function get_oembed_response_data( $post, $width ) {
 		'type'          => 'link',
 	);
 
-	$author = get_userdata( $post->post_author );
+	$author = get_user( $post->post_author );
 
 	if ( $author ) {
 		$data['author_name'] = $author->display_name;
diff --git a/src/wp-includes/link-template.php b/src/wp-includes/link-template.php
index 9f3d9a97ee..738f8e27af 100644
--- a/src/wp-includes/link-template.php
+++ b/src/wp-includes/link-template.php
@@ -263,7 +263,7 @@ function get_permalink( $post = 0, $leavename = false ) {
 
 		$author = '';
 		if ( str_contains( $permalink, '%author%' ) ) {
-			$authordata = get_userdata( $post->post_author );
+			$authordata = get_user( $post->post_author );
 			$author     = $authordata->user_nicename;
 		}
 
@@ -1731,7 +1731,7 @@ function get_edit_user_link( $user_id = null ) {
 		return '';
 	}
 
-	$user = get_userdata( $user_id );
+	$user = get_user( $user_id );
 
 	if ( ! $user ) {
 		return '';
diff --git a/src/wp-includes/ms-functions.php b/src/wp-includes/ms-functions.php
index 913f22543f..1ec9ba6b18 100644
--- a/src/wp-includes/ms-functions.php
+++ b/src/wp-includes/ms-functions.php
@@ -152,7 +152,7 @@ function get_blog_post( $blog_id, $post_id ) {
 function add_user_to_blog( $blog_id, $user_id, $role ) {
 	switch_to_blog( $blog_id );
 
-	$user = get_userdata( $user_id );
+	$user = get_user( $user_id );
 
 	if ( ! $user ) {
 		restore_current_blog();
@@ -267,7 +267,7 @@ function remove_user_from_blog( $user_id, $blog_id = 0, $reassign = 0 ) {
 		update_user_meta( $user_id, 'source_domain', $new_domain );
 	}
 
-	$user = get_userdata( $user_id );
+	$user = get_user( $user_id );
 	if ( ! $user ) {
 		restore_current_blog();
 		return new WP_Error( 'user_does_not_exist', __( 'That user does not exist.' ) );
@@ -1498,7 +1498,7 @@ function newuser_notify_siteadmin( $user_id ) {
 		return false;
 	}
 
-	$user = get_userdata( $user_id );
+	$user = get_user( $user_id );
 
 	$options_site_url = esc_url( network_admin_url( 'settings.php' ) );
 
@@ -1615,7 +1615,7 @@ function wpmu_welcome_notification( $blog_id, $user_id, $password, $title, $meta
 		return false;
 	}
 
-	$user = get_userdata( $user_id );
+	$user = get_user( $user_id );
 
 	$switched_locale = switch_to_user_locale( $user_id );
 
@@ -1714,7 +1714,7 @@ We hope you enjoy your new site. Thanks!
  */
 function wpmu_new_site_admin_notification( $site_id, $user_id ) {
 	$site  = get_site( $site_id );
-	$user  = get_userdata( $user_id );
+	$user  = get_user( $user_id );
 	$email = get_site_option( 'admin_email' );
 
 	if ( ! $site || ! $user || ! $email ) {
@@ -1848,7 +1848,7 @@ function wpmu_welcome_user_notification( $user_id, $password, $meta = array() )
 
 	$welcome_email = get_site_option( 'welcome_user_email' );
 
-	$user = get_userdata( $user_id );
+	$user = get_user( $user_id );
 
 	$switched_locale = switch_to_user_locale( $user_id );
 
@@ -2046,7 +2046,7 @@ function wpmu_log_new_registrations( $blog_id, $user_id ) {
 		$user_id = ! empty( $user_id['user_id'] ) ? $user_id['user_id'] : 0;
 	}
 
-	$user = get_userdata( (int) $user_id );
+	$user = get_user( (int) $user_id );
 	if ( $user ) {
 		$wpdb->insert(
 			$wpdb->registration_log,
diff --git a/src/wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php b/src/wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php
index b0ac65a647..aaf0fe0b21 100644
--- a/src/wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php
+++ b/src/wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php
@@ -712,7 +712,7 @@ class WP_REST_Application_Passwords_Controller extends WP_REST_Controller {
 				return $error;
 			}
 
-			$user = get_userdata( $id );
+			$user = get_user( $id );
 		}
 
 		if ( empty( $user ) || ! $user->exists() ) {
diff --git a/src/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php b/src/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php
index b9a58b63fb..3d5bad922a 100644
--- a/src/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php
+++ b/src/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php
@@ -1293,7 +1293,7 @@ class WP_REST_Posts_Controller extends WP_REST_Controller {
 			$post_author = (int) $request['author'];
 
 			if ( get_current_user_id() !== $post_author ) {
-				$user_obj = get_userdata( $post_author );
+				$user_obj = get_user( $post_author );
 
 				if ( ! $user_obj ) {
 					return new WP_Error(
diff --git a/src/wp-includes/rest-api/endpoints/class-wp-rest-templates-controller.php b/src/wp-includes/rest-api/endpoints/class-wp-rest-templates-controller.php
index 53f8faa755..9c9c89cc95 100644
--- a/src/wp-includes/rest-api/endpoints/class-wp-rest-templates-controller.php
+++ b/src/wp-includes/rest-api/endpoints/class-wp-rest-templates-controller.php
@@ -605,7 +605,7 @@ class WP_REST_Templates_Controller extends WP_REST_Controller {
 			$post_author = (int) $request['author'];
 
 			if ( get_current_user_id() !== $post_author ) {
-				$user_obj = get_userdata( $post_author );
+				$user_obj = get_user( $post_author );
 
 				if ( ! $user_obj ) {
 					return new WP_Error(
diff --git a/src/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php b/src/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php
index 9b38470631..083d39a737 100644
--- a/src/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php
+++ b/src/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php
@@ -407,7 +407,7 @@ class WP_REST_Users_Controller extends WP_REST_Controller {
 			return $error;
 		}
 
-		$user = get_userdata( (int) $id );
+		$user = get_user( (int) $id );
 		if ( empty( $user ) || ! $user->exists() ) {
 			return $error;
 		}
@@ -899,7 +899,7 @@ class WP_REST_Users_Controller extends WP_REST_Controller {
 		}
 
 		if ( ! empty( $reassign ) ) {
-			if ( $reassign === $id || ! get_userdata( $reassign ) ) {
+			if ( $reassign === $id || ! get_user( $reassign ) ) {
 				return new WP_Error(
 					'rest_user_invalid_reassign',
 					__( 'Invalid user ID for reassignment.' ),
diff --git a/src/wp-includes/user.php b/src/wp-includes/user.php
index 5dbff2b929..393c450267 100644
--- a/src/wp-includes/user.php
+++ b/src/wp-includes/user.php
@@ -670,7 +670,7 @@ function get_user_option( $option, $user = 0, $deprecated = '' ) {
 		$user = get_current_user_id();
 	}
 
-	$user = get_userdata( $user );
+	$user = get_user( $user );
 	if ( ! $user ) {
 		return false;
 	}
@@ -843,7 +843,7 @@ function wp_list_users( $args = array() ) {
 	$users = get_users( $query_args );
 
 	foreach ( $users as $user_id ) {
-		$user = get_userdata( $user_id );
+		$user = get_user( $user_id );
 
 		if ( $parsed_args['exclude_admin'] && 'admin' === $user->display_name ) {
 			continue;
@@ -1072,7 +1072,7 @@ function is_user_member_of_blog( $user_id = 0, $blog_id = 0 ) {
 	if ( empty( $user_id ) ) {
 		return false;
 	} else {
-		$user = get_userdata( $user_id );
+		$user = get_user( $user_id );
 		if ( ! $user instanceof WP_User ) {
 			return false;
 		}
@@ -1505,7 +1505,7 @@ function setup_userdata( $for_user_id = 0 ) {
 	if ( ! $for_user_id ) {
 		$for_user_id = get_current_user_id();
 	}
-	$user = get_userdata( $for_user_id );
+	$user = get_user( $for_user_id );
 
 	if ( ! $user ) {
 		$user_ID       = 0;
@@ -1698,7 +1698,7 @@ function wp_dropdown_users( $args = '' ) {
 			}
 
 			if ( ! $found_selected ) {
-				$selected_user = get_userdata( $parsed_args['selected'] );
+				$selected_user = get_user( $parsed_args['selected'] );
 				if ( $selected_user ) {
 					$users[] = $selected_user;
 				}
@@ -2089,7 +2089,7 @@ function wp_insert_user( $userdata ) {
 	if ( ! empty( $userdata['ID'] ) ) {
 		$user_id       = (int) $userdata['ID'];
 		$update        = true;
-		$old_user_data = get_userdata( $user_id );
+		$old_user_data = get_user( $user_id );
 
 		if ( ! $old_user_data ) {
 			return new WP_Error( 'invalid_user_id', __( 'Invalid user ID.' ) );
@@ -2538,7 +2538,7 @@ function wp_update_user( $userdata ) {
 	}
 
 	// First, get all of the original fields.
-	$user_obj = get_userdata( $user_id );
+	$user_obj = get_user( $user_id );
 	if ( ! $user_obj ) {
 		return new WP_Error( 'invalid_user_id', __( 'Invalid user ID.' ) );
 	}
@@ -4973,7 +4973,7 @@ function wp_is_application_passwords_available_for_user( $user ) {
 	}
 
 	if ( ! is_object( $user ) ) {
-		$user = get_userdata( $user );
+		$user = get_user( $user );
 	}
 
 	if ( ! $user || ! $user->exists() ) {
@@ -5057,7 +5057,7 @@ function wp_cache_set_users_last_changed() {
  */
 function wp_is_password_reset_allowed_for_user( $user ) {
 	if ( ! is_object( $user ) ) {
-		$user = get_userdata( $user );
+		$user = get_user( $user );
 	}
 
 	if ( ! $user || ! $user->exists() ) {

diff --git a/src/wp-includes/pluggable.php b/src/wp-includes/pluggable.php
index c0bbcfe02e..bbf0cc4161 100644
--- a/src/wp-includes/pluggable.php
+++ b/src/wp-includes/pluggable.php
@@ -71,8 +71,8 @@ if ( ! function_exists( 'wp_get_current_user' ) ) :
 	}
 endif;
 
-if ( ! function_exists( 'get_userdata' ) ) :
-	/**
+if ( ! function_exists( 'get_user' ) ) :
+	/*
 	 * Retrieves user info by user ID.
 	 *
 	 * @since 0.71
@@ -80,7 +80,7 @@ if ( ! function_exists( 'get_userdata' ) ) :
 	 * @param int $user_id User ID
 	 * @return WP_User|false WP_User object on success, false on failure.
 	 */
-	function get_userdata( $user_id ) {
+	function get_user( $user_id ) { // get_userdata()
 		return get_user_by( 'id', $user_id );
 	}
 endif;
@@ -114,7 +114,7 @@ endif;
 
 if ( ! function_exists( 'cache_users' ) ) :
 	/**
 	 * Retrieves info for user lists to prevent multiple queries by get_userdata().
 	 *
 	 * @since 3.0.0
 	 *
@@ -855,7 +855,7 @@ if ( ! function_exists( 'wp_generate_auth_cookie' ) ) :
 	 * @return string Authentication cookie contents. Empty string if user does not exist.
 	 */
 	function wp_generate_auth_cookie( $user_id, $expiration, $scheme = 'auth', $token = '' ) {
-		$user = get_userdata( $user_id );
+		$user = get_user( $user_id );
 		if ( ! $user ) {
 			return '';
 		}
@@ -1653,7 +1653,7 @@ if ( ! function_exists( 'wp_notify_postauthor' ) ) :
 		}
 
 		$post   = get_post( $comment->comment_post_ID );
-		$author = get_userdata( $post->post_author );
+		$author = get_user( $post->post_author );
 
 		// Who to notify? By default, just the post author, but others can be added.
 		$emails = array();
@@ -1899,7 +1899,7 @@ if ( ! function_exists( 'wp_notify_moderator' ) ) :
 
 		$comment = get_comment( $comment_id );
 		$post    = get_post( $comment->comment_post_ID );
-		$user    = get_userdata( $post->post_author );
+		$user    = get_user( $post->post_author );
 		// Send to the administration and to the post author if the author can modify the comment.
 		$emails = array( get_option( 'admin_email' ) );
 		if ( $user && user_can( $user->ID, 'edit_comment', $comment_id ) && ! empty( $user->user_email ) ) {
@@ -2133,7 +2133,7 @@ if ( ! function_exists( 'wp_new_user_notification' ) ) :
 			return;
 		}
 
-		$user = get_userdata( $user_id );
+		$user = get_user( $user_id );
 
 		/*
 		 * The blogname option is escaped with esc_html() on the way into the database in sanitize_option().
@@ -114,7 +114,7 @@ endif;
 if ( ! function_exists( 'cache_users' ) ) :
 	/**
-	 * Retrieves info for user lists to prevent multiple queries by get_userdata().
+	 * Retrieves info for user lists to prevent multiple queries by get_user().
 	 *
 	 * @since 3.0.0